import React, { ReactNode } from 'react';
import { BundledLanguage, BundledTheme } from 'shiki';
import { Element } from 'hast';
export { Element } from 'hast';

interface ShikiHighlighterProps {
    /**
     * The programming language for syntax highlighting
     * @see https://shiki.style/languages
     */
    language: BundledLanguage;
    /**
     * The code to be highlighted
     */
    children: string;
    /**
     * The color theme for syntax highlighting, only Shiki themes are supported at this time
     * @see https://shiki.style/themes
     */
    theme: BundledTheme;
    /**
     * Controls the application of default styles to the generated code blocks
     *
     * Default styles include padding, overflow handling, border radius, language label styling, and font settings
     * @default true
     */
    addDefaultStyles?: boolean;
    /**
     * Add custom inline styles to the generated code block
     */
    style?: React.CSSProperties;
    /**
     * Add custom CSS class names to the generated code block
     */
    className?: string;
    /**
     * Whether to show the language label
     * @default true
     */
    showLanguage?: boolean;
    /**
     * The HTML element that wraps the generated code block.
     * @default 'pre'
     */
    as?: React.ElementType;
}
/**
 * ShikiHighlighter is a React component that provides syntax highlighting for code snippets.
 *
 * It uses the Shiki library to render beautiful, theme-based syntax highlighting.
 *
 * @example
 * ```tsx
 * <ShikiHighlighter language="tsx" theme="vitesse-black">
 *   {code.trim()}
 * </ShikiHighlighter>
 * ```
 */
declare const ShikiHighlighter: ({ language, theme, addDefaultStyles, style, className, showLanguage, children: code, as: Element, }: ShikiHighlighterProps) => React.ReactElement;

/**
 *
 * `useShikiHighlighter` is a custom hook that takes in the code to be highlighted, the language, and the theme, and returns the highlighted code parsed as a ReactNode.
 *
 * @example
 * ```tsx
 * const highlightedCode = useShikiHighlighter(code, language, theme);
 * ```
 *
 */
declare const useShikiHighlighter: (code: string, lang: BundledLanguage | undefined, theme: BundledTheme) => ReactNode | null;

declare const isInlineCode: (node: Element) => boolean;

export { ShikiHighlighter as default, isInlineCode, useShikiHighlighter };
